###########################################################################
#  DSpace: Product to embed a DSpace repository within a Plone site.
#
#  https://svn.plone.org/svn/collective/DSpace
#
# This is a product that enables the user to connect to
# a default DSpace application. This application is a digital repository
# for articles, books, courseware, journals, websites and thesis material.
#
#  Copyright (C) 2007  Cranfield University, UK
#  Written by: The Development Team, DCMT Cranfield University
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
###########################################################################

#
# Test DSpace post create and post edit methods
#

from base import DSpaceTestCase

from zExceptions import Unauthorized

class TestContentCreation(DSpaceTestCase):
    """Ensure content types can be created and edited"""

    def afterSetUp(self):
        self.folder.invokeFactory('DSpace Instance', 'dsi1')

    def testSkinsFolderAdded(self):
        dsi1 = getattr(self.folder, 'dsi1')
        dsi1.at_post_create_script()
        self.failUnless('system' in dsi1.objectIds())
        self.failUnless('getCollectionName' in dsi1['system'].objectIds())

    def testDatabaseConnectionAdded(self):
        dsi1 = getattr(self.folder, 'dsi1')
        dsi1.at_post_create_script()
        self.failUnless('DSpace' in dsi1.objectIds())

    def testDatabaseConnectionValues(self):
        dsi1 = getattr(self.folder, 'dsi1')
        dsi1.setDbName('DbName')
        dsi1.setDbUser('UserName')
        dsi1.setDbHost('HostName')
        dsi1.setDbPassword('password')
        dsi1.at_post_create_script()
        dbase_connection = dsi1['DSpace']
        self.assertEqual(dbase_connection.connection_string,
                         'dbname=DbName user=UserName host=HostName password=password')

if  __name__ == '__main__':
    framework()

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestContentCreation))
    return suite
