###########################################################################
#  DSpace: Product to embed a DSpace repository within a Plone site.
#
#  https://svn.plone.org/svn/collective/DSpace
#
# This is a product that enables the user to connect to
# a default DSpace application. This application is a digital repository
# for articles, books, courseware, journals, websites and thesis material.
#
#  Copyright (C) 2007  Cranfield University, UK
#  Written by: The Development Team, DCMT Cranfield University
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
###########################################################################

#
# Test DSpace setup
#

from base import DSpaceTestCase

from zExceptions import Unauthorized

class TestInstallation(DSpaceTestCase):
    """Ensure DSpace is installed correctly"""

    def afterSetUp(self):
        self.skins      = self.portal.portal_skins
        self.types      = self.portal.portal_types
        self.factory    = self.portal.portal_factory

        self.metaTypes = ('DSpace Instance',)

    def testSkinLayersInstalled(self):
        self.failIf('DSpace' in self.skins.objectIds())

    def testPortalFactorySetup(self):
        self.failUnless('DSpace Instance' in self.factory.getFactoryTypes())

    def testTypesInstalled(self):
        for t in self.metaTypes:
            self.failUnless(t in self.types.objectIds())

class TestContentCreation(DSpaceTestCase):
    """Ensure content types can be created and edited"""

    def afterSetUp(self):
        self.folder.invokeFactory('DSpace Instance', 'dsi1')

    def testCreateDSpaceInstance(self):
        self.failUnless('dsi1' in self.folder.objectIds())

    def testEditDSpaceInstance(self):
        dsi1 = getattr(self.folder, 'dsi1')
        dsi1.setTitle('Test Title')
        self.assertEqual(dsi1.Title(), 'Test Title')

if  __name__ == '__main__':
    framework()

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestInstallation))
    suite.addTest(makeSuite(TestContentCreation))
    return suite
